@@ -1,5 +1,8 @@
 tdval <- function( vf ) {
 
+  texteval <- "vfsettings$locini"
+  locini   <- eval( parse( text = texteval ) )
+
 # get normal age-corrected values
   td <- vf
   for( i in 1:nrow( td ) ) {
@@ -13,11 +16,11 @@ tdval <- function( vf ) {
     texteval <- paste( "vfenv$nv$", td$tpattern[i], "_", td$talgorithm[i], "$agelm", sep = "" )
     agelm <- eval( parse( text = texteval ) )
 # calculate total-deviation values
-    td[i,visualFields::vfsettings$locini:( visualFields::vfsettings$locini - 1 + locnum )] <- td[i,visualFields::vfsettings$locini:( visualFields::vfsettings$locini - 1 + locnum )] - ( agelm$intercept + agelm$slope * td$sage[i] )
+    td[i,locini:( locini - 1 + locnum )] <- td[i,locini:( locini - 1 + locnum )] - ( agelm$intercept + agelm$slope * td$sage[i] )
   }
 
 # Fill with NA the blind-spot sensitivities
-  if( all( !is.na( bspos ) ) ) td[,bspos + visualFields::vfsettings$locini - 1] <- NA 
+  if( all( !is.na( bspos[1] ) ) ) td[,bspos + locini - 1] <- NA 
 
   return( td )
 }
\ No newline at end of file
